# Detectors

???+ abstract "`cryojax.simulator.AbstractDetector`"
    ::: cryojax.simulator.AbstractDetector
        options:
            members:
                - compute_expected_counts
                - sample_counts
